/*! ****************************************************************************
 * @file:    adi_rtc_def.h
 * @brief:   RTC def file
 * -----------------------------------------------------------------------------
 * Copyright (c) 2010-2019 Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * For license terms and conditions, please refer to the '*EZDFP Click Thru SLA'
 * file in the License subdirectory of this pack.
 *
 ******************************************************************************/
#ifndef ADI_RTC_DEF_H__
#define ADI_RTC_DEF_H__

/*! \cond PRIVATE */
#define ADI_RTC_NUM_INSTANCE 2u



#define ADI_RTC_INT_ENA_MASK_CR0         0XF804u

#define ADI_RTC_INT_ENA_MASK_CR1         0X1Fu

#define ADI_RTC_INT_ENA_MASK_CR2IC       0xF41C
#define ADI_RTC_INT_ENA_MASK_CR3SS       0x1FFE
#define ADI_RTC_INT_ENA_MASK_CR4SS       0x0E0E
#define ADI_RTC_INT_ENA_MASK_CR5SSS      0x0FFF

/* Mask to select pend/sync write status bits */
#define ADI_RTC_WRITE_STATUS_MASK        0X3F80u


#define ADI_RTC_TRIM_MASK (BITM_RTC_TRM_VALUE | BITM_RTC_TRM_ADD|BITM_RTC_TRM_IVL | BITM_RTC_TRM_IVL2EXPMIN )

#define  ALWAYS_PEND_BEFORE_WRITE(reg,mask) while((pDevice->pRTCRegs->reg&(mask))!=0u)\
        {\
        }

#define  ALWAYS_SYNC_AFTER_WRITE(reg,mask) while((pDevice->pRTCRegs->reg&(mask))!=(mask))\
        {\
        }

#if (ADI_RTC_CFG_ENABLE_SAFE_WRITE == 1)
    /* pause on pending writes to CR to avoid data loss */

#ifdef __ICCARM__
/*
* Pm154 (rule 19.10): in the definition of a function-like macro, each instance
*                     of a parameter shall be enclosed in parentheses
*   Parameter use without parentheses needed for struct field name in register access macro.
*/
#pragma diag_suppress=Pm154
#endif /* __ICCARM__ */

#define  PEND_BEFORE_WRITE(reg,mask) while((pDevice->pRTCRegs->reg&(mask))!=0u)\
        {\
        }

#define  SYNC_AFTER_WRITE(reg,mask) while((pDevice->pRTCRegs->reg&(mask))!=(mask))\
        {\
        }

#ifdef __ICCARM__
#pragma diag_default=Pm154
#endif /* __ICCARM__ */

#else
    /* pause on pending writes to CR to avoid data loss */
#define  PEND_BEFORE_WRITE(reg,mask)
#define  SYNC_AFTER_WRITE(reg,mask)
#endif

/*
 * The following is used for static configuration
 */
typedef struct
{
    uint16_t    CR0;             /*!< CR0 16 bit control register-0 value */
    uint16_t    CR1;             /*!< CR1 16 bit control register-1 value */
    uint16_t    CNT0;            /*!< CNT0 16 bit count register value */
    uint16_t    CNT1;            /*!< CNT1 16 bit count register value */

    uint16_t    ALM0;            /*!< ALM0 16 bit integer part of alarm value */
    uint16_t    ALM1;            /*!< ALM1 16 bit integer part of alarm value */
    uint16_t    ALM2;            /*!< ALM2 16 bit integer part of alarm value */
    uint16_t    TRIM;            /*!< 16 bit trim register value */
    uint16_t    CR2IC;           /*!< CR2IC 16 bit control (which controls the input capture ) register-2 value */
    uint16_t    CR3SS;           /*!< CR3SS 16 bit control ( Controls enabling sensor strobe /IRQ etc )register-3 value */
    uint16_t    CR4SS;           /*!< CR4SS 16 bit control ( controls Auto reload  and mask for sensor strobe  ) register-4 value */
    uint16_t    SSMSK;           /*!< OCMSK Mask register for sensor strobe channel */
    uint16_t    SS1;             /*!< 16 bit Sensor strobe value */
#if defined(__ADUCM302x__)
    uint16_t    SS1ARL;          /*!< 16 bit Auto reload value */
#elif defined(__ADUCM4x50__)
    uint16_t    SS1LOWDUR;       /*!< 16 bit Auto-Reload Low Duration value for SensorStrobe Channel 1 */
    uint16_t    SS1HIGHDUR;      /*!< 16 bit Auto-Reload High Duration value for SensorStrobe Channel 1*/
    uint16_t    SS2LOWDUR;       /*!< 16 bit Auto-Reload Low Duration value for SensorStrobe Channel 2 */
    uint16_t    SS2HIGHDUR;      /*!< 16 bit Auto-Reload High Duration value for SensorStrobe Channel 2*/
    uint16_t    SS3LOWDUR;       /*!< 16 bit Auto-Reload Low Duration value for SensorStrobe Channel 3 */
    uint16_t    SS3HIGHDUR;      /*!< 16 bit Auto-Reload High Duration value for SensorStrobe Channel 3*/

    uint16_t    CR5SSS;          /*!< Configure Sensor Strobe Channel GPIO Sampling Register */
    uint16_t    CR6SSS;          /*!< Configure Sensor Strobe Channel GPIO Sampling Register */
    uint16_t    CR7SSS;          /*!< Configure Sensor Strobe Channel GPIO Sampling Register */
#endif
    uint16_t    GPMUX0;          /*!< Control register for selecting a GPIO (pin) as data to be sampled by a Sensor Strobe  channel */
    uint16_t    GPMUX1;          /*!< Control register for selecting a GPIO (pin) as data to be sampled by a Sensor Strobe  channel */
}ADI_RTC_CONFIG;

/* Device information structure */
typedef struct _ADI_RTC_DEVICE_INFO
{
    volatile ADI_RTC_TypeDef  *pRTCRegs;   /* Base address of the  SPORT registers */
    const IRQn_Type            eIRQn;      /* IRQn */
    ADI_RTC_HANDLE             hDevice;    /* RTC handle */
}ADI_RTC_DEVICE_INFO;

/*! RTC driver instance data */
typedef struct _ADI_RTC_DEVICE
{
    volatile ADI_RTC_TypeDef *pRTCRegs;    /* Pointer to RTC Memory Mapped Registers */

    ADI_CALLBACK              pfCallback;  /*  Function pointer for callback function. */

    void                     *pCBParam;    /*  Parameter to callback function. */
    IRQn_Type                eIRQn;        /* IRQn */
    uint32_t  cbWatch;
    ADI_RTC_DEVICE_INFO      *pDeviceInfo; /*  Parameter to callback function. */

} ADI_RTC_DEVICE;


static void rtc_init(ADI_RTC_DEVICE *pDevice,ADI_RTC_CONFIG *pConfig);

#ifdef ADI_DEBUG
static ADI_RTC_RESULT ValidateHandle( ADI_RTC_DEVICE *pInDevice);
#endif
/*! \endcond */
#endif /* ADI_RTC_DEF_H__ */
